Author: cgutman
Date: Thu May 6 01:16:17 2010
New Revision: 47109
URL:
http://svn.reactos.org/svn/reactos?rev=47109&view=rev
Log:
[VIDEOPRT]
- Also check for the BASEVIDEO option set and return true in that case also
- Fixes a bug with boot time (F8) options on my WC
Modified:
trunk/reactos/drivers/video/videoprt/videoprt.c
Modified: trunk/reactos/drivers/video/videoprt/videoprt.c
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/video/videoprt/vid…
==============================================================================
--- trunk/reactos/drivers/video/videoprt/videoprt.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/video/videoprt/videoprt.c [iso-8859-1] Thu May 6 01:16:17 2010
@@ -1523,8 +1523,9 @@
return FALSE;
}
- /* Check if NOVESA is present in the start options */
- if (wcsstr((PWCHAR)KeyInfo->Data, L"NOVESA"))
+ /* Check if NOVESA or BASEVIDEO is present in the start options */
+ if (wcsstr((PWCHAR)KeyInfo->Data, L"NOVESA") ||
+ wcsstr((PWCHAR)KeyInfo->Data, L"BASEVIDEO"))
{
VideoPortDebugPrint(Info, "VESA mode disabled\n");
ExFreePool(KeyInfo);